Description Usage Format Source
Data of catch for different locations in Sanata Barbara for different species
1 |
A data frame with 6 rows and 7 variables:
fish species
number of fish of that species catch at location A
number of fish of that species catch at location B
number of fish of that species catch at location C
number of fish of that species catch at location D
number of fish of that species catch at location E
number of fish of that species catch at location F
Ignacia Rivera
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.